-- Создание таблицы, если она не существует
CREATE TABLE IF NOT EXISTS `#__monetka_users` (
    `id` INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
    `user_id` INT(11) NOT NULL,
    `username` VARCHAR(255) NOT NULL,
    `balance` DECIMAL(10,2) DEFAULT 0,
    PRIMARY KEY (`id`),
    UNIQUE KEY `unique_user` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;


-- Вставка данных пользователей Joomla в таблицу
INSERT INTO `#__monetka_users` (`user_id`, `username`, `balance`)
SELECT 
    u.id AS user_id,
    u.username,
    0 AS balance
FROM 
    `#__users` AS u
WHERE NOT EXISTS (
    SELECT 1 FROM `#__monetka_users` AS existing
    WHERE existing.user_id = u.id
);
 

CREATE TABLE IF NOT EXISTS `#__monetka_cryptocurrencies` (
    `id` INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
    `name` VARCHAR(255) NOT NULL,
    `symbol` VARCHAR(10) NOT NULL,
    `price_rub` DECIMAL(15,2) DEFAULT NULL,
    `price_usd` DECIMAL(15,2) DEFAULT NULL,
    `last_updated` DATETIME DEFAULT NULL,
    PRIMARY KEY (`id`),
    UNIQUE KEY `symbol` (`symbol`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

CREATE TABLE IF NOT EXISTS `#__monetka_settings` (
    `id` INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
    `site_coin_name` VARCHAR(255) DEFAULT NULL,
    `coins_per_group` INT(11) DEFAULT NULL,
    `site_fee_coins` FLOAT DEFAULT NULL,
    `kucoin_api_key` VARCHAR(255) DEFAULT NULL,
    `kucoin_api_secret` VARCHAR(255) DEFAULT NULL,
    `kucoin_api_passphrase` VARCHAR(255) DEFAULT NULL,
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- Обновление начальной записи с новыми полями
INSERT INTO `#__monetka_settings` 
(`id`, `site_coin_name`, `coins_per_group`, `site_fee_coins`, `kucoin_api_key`, `kucoin_api_secret`, `kucoin_api_passphrase`) 
VALUES 
(1, 'Монетка', 0, 0.0, NULL, NULL, NULL)
ON DUPLICATE KEY UPDATE 
    `site_coin_name` = VALUES(`site_coin_name`),
    `coins_per_group` = VALUES(`coins_per_group`),
    `site_fee_coins` = VALUES(`site_fee_coins`),
    `kucoin_api_key` = VALUES(`kucoin_api_key`),
    `kucoin_api_secret` = VALUES(`kucoin_api_secret`),
    `kucoin_api_passphrase` = VALUES(`kucoin_api_passphrase`);

CREATE TABLE IF NOT EXISTS `#__monetka_items` (
    `id` INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
    `title` VARCHAR(255) NOT NULL,
    `alias` VARCHAR(255) NOT NULL,
    `catid` INT(11) NOT NULL,
    `state` TINYINT(1) NOT NULL DEFAULT 1,
    `created` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `created_by` INT(11) NOT NULL,
    `modified` DATETIME DEFAULT NULL,
    `modified_by` INT(11) DEFAULT NULL,
    `params` TEXT DEFAULT NULL,
    `language` CHAR(7) DEFAULT '*',
    PRIMARY KEY (`id`),
    KEY `idx_catid` (`catid`),
    KEY `idx_state` (`state`),
    KEY `idx_language` (`language`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
INSERT INTO `#__monetka_items` (`title`, `alias`, `catid`, `state`, `created_by`, `language`) 
VALUES 
('Пример элемента 1', 'primer-elementa-1', 1, 1, 1, '*'),
('Пример элемента 2', 'primer-elementa-2', 1, 1, 1, '*');
 
